@@ -10,7 +10,7 @@ class ResourceSearch(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.crs = build('cloudresourcesearch', 'v1', credentials=credentials)
+        self.crs = build('cloudresourcesearch', 'v1', credentials=credentials, cache_discovery=False)
 
     def search(self, query, orderBy=None, pageSize=None, pageToken=None):
         """Return results from a cloud research search."""
