@@ -10,7 +10,7 @@ class Vault(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.vault = build('vault', 'v1', credentials=credentials)
+        self.vault = build('vault', 'v1', credentials=credentials, cache_discovery=False)
 
     def add_held_accounts(self, matterId, holdId, body):
         """Return a list of matters."""
